@@ -14,7 +14,7 @@ When we initially build an Ansible major release, we'll use certain versions of
 don't want to install backwards incompatible collections until the next major Ansible release.
 """
 
-from typing import TYPE_CHECKING, Dict, List, Mapping, NamedTuple, Optional
+from typing import TYPE_CHECKING, Dict, List, Mapping, NamedTuple, Optional, Union
 
 from packaging.version import Version as PypiVer
 
@@ -36,12 +36,12 @@ def parse_pieces_file(pieces_file: str) -> List[str]:
     with open(pieces_file, 'rb') as f:
         contents = f.read()
 
-    contents = contents.decode('utf-8')
+    decoded_contents = contents.decode('utf-8')
     # One collection per line, ignoring comments and empty lines
     # TODO: PY3.8:
-    # collections = [c for line in contents.split('\n')
+    # collections = [c for line in decoded_contents.split('\n')
     #                if (c := line.strip()) and not c.startswith('#')]
-    collections = [line.strip() for line in contents.split('\n')
+    collections = [line.strip() for line in decoded_contents.split('\n')
                    if line.strip() and not line.strip().startswith('#')]
     return collections
 
@@ -113,8 +113,9 @@ class DepsFile:
         """Parse the deps from a dependency file."""
         return _parse_name_version_spec_file(self.filename)
 
-    def write(self, ansible_version: str, ansible_core_version: str,
-              included_versions: Mapping[str, str]) -> None:
+    def write(self, ansible_version: Union[str, 'PypiVer'],
+              ansible_core_version: Union[str, 'PypiVer'],
+              included_versions: Union[Mapping[str, str], Mapping[str, 'SemVer']]) -> None:
         """
         Write a list of all the dependent collections included in this Ansible release.
 
@@ -122,15 +123,22 @@ class DepsFile:
         :arg ansible_core_version: The version of Ansible-core that will be depended on.
         :arg included_versions: Dictionary mapping collection names to the version range in this
             version of Ansible.
+
+        WARNING: This function will no longer accept version objects in the ansible_core_version
+                 and included_versions parameters, and will require a PypiVer object in the
+                 ansible_version parameter in antsibull-core 2.0.0.
         """
         records = []
         for dep, version in included_versions.items():
             records.append(f'{dep}: {version}')
         records.sort()
 
+        if not isinstance(ansible_version, PypiVer):
+            ansible_version = PypiVer(ansible_version)
+
         with open(self.filename, 'w', encoding='utf-8') as f:
             f.write(f'_ansible_version: {ansible_version}\n')
-            if PypiVer(ansible_version).major > 5:
+            if ansible_version.major > 5:
                 f.write(f'_ansible_core_version: {ansible_core_version}\n')
             else:
                 f.write(f'_ansible_base_version: {ansible_core_version}\n')
