@@ -62,21 +62,23 @@ class AppContext(BaseModel):
 
     extra: ContextDict = ContextDict()
     # pyre-ignore[8]: https://github.com/samuelcolvin/pydantic/issues/1684
-    ansible_base_url: p.HttpUrl = 'https://github.com/ansible/ansible/'
+    ansible_base_url: p.HttpUrl = 'https://github.com/ansible/ansible/'  # type: ignore[assignment]
     breadcrumbs: p.StrictBool = True
     # pyre-ignore[8]: https://github.com/samuelcolvin/pydantic/issues/1684
-    galaxy_url: p.HttpUrl = 'https://galaxy.ansible.com/'
+    galaxy_url: p.HttpUrl = 'https://galaxy.ansible.com/'  # type: ignore[assignment]
     indexes: p.StrictBool = True
     logging_cfg: LoggingModel = LoggingModel.parse_obj(DEFAULT_LOGGING_CONFIG)
     # pyre-ignore[8]: https://github.com/samuelcolvin/pydantic/issues/1684
-    pypi_url: p.HttpUrl = 'https://pypi.org/'
+    pypi_url: p.HttpUrl = 'https://pypi.org/'  # type: ignore[assignment]
     use_html_blobs: p.StrictBool = False
     collection_cache: t.Optional[str] = None
 
-    _convert_bools = p.validator('breadcrumbs', 'indexes', 'use_html_blobs',
-                                 pre=True, allow_reuse=True)(convert_bool)
-    _convert_paths = p.validator('collection_cache',
-                                 pre=True, allow_reuse=True)(convert_path)
+    # pylint: disable-next=unused-private-member
+    __convert_bools = p.validator('breadcrumbs', 'indexes', 'use_html_blobs',
+                                  pre=True, allow_reuse=True)(convert_bool)
+    # pylint: disable-next=unused-private-member
+    __convert_paths = p.validator('collection_cache',
+                                  pre=True, allow_reuse=True)(convert_path)
 
 
 class LibContext(BaseModel):
@@ -106,4 +108,5 @@ class LibContext(BaseModel):
     thread_max: int = 8
     file_check_content: int = 262144
 
-    _convert_nones = p.validator('process_max', pre=True, allow_reuse=True)(convert_none)
+    # pylint: disable-next=unused-private-member
+    __convert_nones = p.validator('process_max', pre=True, allow_reuse=True)(convert_none)
